@@ -15,7 +15,7 @@
 */
 
 # Turn off PHP errors
-error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT & ~E_WARNING);
+@error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT & ~E_WARNING);
 
 
 //Set no caching
@@ -57,8 +57,8 @@ try {
 	}
 
 	/* Check for PHP version */
-	if (!version_compare(PHP_VERSION, '5.2.0', '>=')) {
-		throw new Exception('phpVirtualBox requires PHP >= 5.2.0, but this server is running version '. PHP_VERSION .'. Please upgrade PHP.');
+	if (!version_compare(PHP_VERSION, '8.1.0', '>=')) {
+		throw new Exception('phpVirtualBox requires PHP >= 8.1.0, but this server is running version '. PHP_VERSION .'. Please upgrade PHP.');
 	}
 
 	# Only valid function chars
@@ -334,6 +334,9 @@ try {
 
 	// Just append to $vbox->errors and let it get
 	// taken care of below
+	if(!isset($vbox)) {
+		$vbox = new stdClass();
+	}
 	if(!$vbox || !$vbox->errors) {
 		$vbox->errors = array();
 	}
@@ -342,7 +345,7 @@ try {
 
 
 // Add any messages
-if($vbox && count($vbox->messages)) {
+if($vbox && isset($vbox->messages)?count($vbox->messages):false) {
 	foreach($vbox->messages as $m)
 		$response['messages'][] = 'vboxconnector('.$request['fn'] .'): ' . $m;
 }
@@ -360,7 +363,7 @@ if($vbox && $vbox->errors) {
 		if($e->getCode() == vboxconnector::PHPVB_ERRNO_CONNECT && isset($vbox->settings))
 			$d .= "\n\nLocation:" . $vbox->settings->location;
 
-		$response['messages'][] = htmlentities($e->getMessage()).' ' . htmlentities($details);
+		$response['messages'][] = htmlentities($e->getMessage()). htmlentities(' '. $details);
 
 		$response['errors'][] = array(
 			'error'=> ($e->getCode() & vboxconnector::PHPVB_ERRNO_HTML ? $e->getMessage() : htmlentities($e->getMessage())),
